@@ -4,7 +4,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
- 'ARFLAGS': 'rc',
+ 'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
@@ -12,10 +12,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BINLIBDEST': '/usr/local/lib/python3.6',
  'BLDLIBRARY': '-L. -lpython3.6m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+              '-L/usr/obj/ports/Python-3.6.8/Python-3.6.8',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'i386-unknown-openbsd6.4',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd6.5',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -33,9 +33,10 @@ build_time_vars = {'ABIFLAGS': 'm',
                             '-Wstrict-prototypes',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
+ 'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
                 "'--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.6.6/Python-3.6.6' "
+                "'--srcdir=/usr/obj/ports/Python-3.6.8/Python-3.6.8' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
@@ -46,8 +47,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.6.6/Python-3.6.6/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.6.6/Python-3.6.6/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.6.8/Python-3.6.8/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.6.8/Python-3.6.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -385,7 +386,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
- 'HAVE_STD_ATOMIC': 0,
+ 'HAVE_STD_ATOMIC': 1,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -479,27 +480,28 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.4',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.5',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.6m '
                    '/usr/local/include/python3.6m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.6m',
- 'INSTALL': '/usr/obj/ports/Python-3.6.6/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.6.6/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.6.6/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.6.6/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.6.6/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-3.6.8/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.6.8/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.6.8/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.6.8/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.6.8/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.6m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.8/Python-3.6.8',
+ 'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.6m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+             '-L/usr/obj/ports/Python-3.6.8/Python-3.6.8',
  'LDVERSION': '3.6m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.6',
@@ -601,18 +603,20 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes -I. '
                    '-I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
+                    '-L/usr/obj/ports/Python-3.6.8/Python-3.6.8',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.6.8/Python-3.6.8',
+ 'PY_LDFLAGS_NODIST': '',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RANLIB': 'ranlib',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.8/Python-3.6.8',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -653,10 +657,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.6/Python-3.6.6 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.8/Python-3.6.8 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.6/Python-3.6.6 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.6.8/Python-3.6.8 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -681,8 +685,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.6.6/Python-3.6.6',
- 'abs_srcdir': '/usr/obj/ports/Python-3.6.6/Python-3.6.6',
+ 'abs_builddir': '/usr/obj/ports/Python-3.6.8/Python-3.6.8',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.6.8/Python-3.6.8',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
